<?php
if (!defined('ABSPATH'))
    exit;

if (!class_exists('rbyprAdminMenu')) {

    /**
     * Class to handle the Admin Menu page for Easy Table Reservations
     *
     * @since 1.3
     */
    class rbyprAdminMenu {

        private $successMsg = false;
        private $errorMsg = false;

        public function __construct() {
            // Add a admin menu
            add_action('admin_menu', array($this, 'rbypr_add_dashboard_to_menu'));
            add_filter('rbytb_insert_booking_data', array($this, 'insert_booking_data'), 10, 2);
        }

        function rbypr_add_dashboard_to_menu() {
            add_menu_page('My Page Title', 'Footer Content Ratation', '', 'my-menu', 'my_menu_output', 'dashicons-calendar');

            add_submenu_page('my-menu', 'Footer Content Ratation - Settings', 'Settings', 'manage_options', 'rbypr-settings', array($this, 'rbypr_settings'));
        }

        public function rbypr_settings() {
            global $rybtb_controller;
            if (isset($_POST['savesetting'])) {
                $timer = sanitize_text_field($_POST['timer']);
                $totalpost = sanitize_text_field($_POST['totalpost']);
                $alignment = sanitize_text_field($_POST['alignment']);
                $isHomeDisplay = sanitize_text_field($_POST['isHomeDisplay']);                
                $default_img_path = sanitize_text_field($_POST['default_img_path']);
                $allSettings = array(
                    'timer' => $timer,
                    'totalpost' => $totalpost,
                    'alignment' => $alignment,
                    'isHomeDisplay' => $isHomeDisplay,
                    'default_img_path' => $default_img_path,
                );
                update_option('rbypr_default', serialize($allSettings));
            }
            $getdefval = unserialize(get_option('rbypr_default'));
            $timeinterval = $getdefval['timer'];
            $totalpost = $getdefval['totalpost'];
            $alignment = $getdefval['alignment'];
            $isHomeDisplay = $getdefval['isHomeDisplay'];
            $default_img_path = $getdefval['default_img_path'];
            ?>
            <div class="wrap">
                <h1 id="add-new-table">
            <?php _e('Footer Content Rotation Settings', RBYPR_PLUGIN_NAME); ?></h1>
                <div class="row">

                    <form method="post" name="filterbooking" action="?page=rbypr-settings" class="validate form">
                        <input name="savesetting" type="hidden" value="1">
                        <table class="form-table" role="presentation">
                            <tbody>
                                <tr class="form-field form-required">							
                                    <th scope="row"><?php _e('Rotation Time Interval', RBYTB_PLUGIN_NAME); ?></th>
                                    <td>
                                        <p class="description"><?php _e('Define the Timer during next article rotate(in second).', RBYTB_PLUGIN_NAME); ?></p>
                                        <div>
                                            <span> &nbsp; </span>
                                            <span class="css-clock">
                                                <select name="timer" required style="width:100px" >
                                                    <option value=""><?php _e('--Seconds--', RBYTB_PLUGIN_NAME); ?></option>
                                                    <?php
                                                    for ($i = 5; $i < 61; $i++) {
                                                        $selected = $i == $timeinterval ? 'selected' : '';
                                                        echo "<option value='" . $i . "' " . $selected . ">" . $i . "</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </span>
                                        </div>
                                    </td>
                                </tr>
                                <tr class="form-field form-required">
                                    <th scope="row"><?php _e('Number of Post', RBYTB_PLUGIN_NAME); ?></th>
                                    <td>
                                        <p class="description"><?php _e('Select the number of Post which display in Que.', RBYTB_PLUGIN_NAME); ?></p>
                                        <div>
                                            <select name="totalpost" required style="width:150px">									
            <?php
            for ($i = 3; $i < 21; $i++) {
                $selected = $i == $totalpost ? 'selected' : '';
                echo "<option value='" . $i . "' " . $selected . ">" . $i . "</option>";
            }
            ?>
                                            </select>						
                                        </div>
                                    </td>
                                </tr>
                                <tr class="form-field form-required" style="display:none">
                                    <th scope="row"><?php _e('Alignment', RBYTB_PLUGIN_NAME); ?></th>
                                    <td>
                                        <p class="description"><?php _e('Select the post box alignment.', RBYTB_PLUGIN_NAME); ?></p>
                                        <div>
                                            <select name="alignment" required style="width:150px">									
                                                <option value="left" <?php if ($alignment == 'left') echo "selected"; ?>>Left</option>
                                                <option value="center" <?php if ($alignment == 'center') echo "selected"; ?>>Center</option>
                                                <option value="right" <?php if ($alignment == 'right') echo "selected"; ?>>Right</option>
                                            </select>						
                                        </div>
                                    </td>
                                </tr>
                                <tr class="form-field form-required" >
                                    <th scope="row"><?php _e('Hide for Home page', RBYTB_PLUGIN_NAME); ?></th>
                                    <td>
                                        <p class="description"><?php _e('If yes, Box will not display on home page only .', RBYTB_PLUGIN_NAME); ?></p>
                                        <div>
                                             <select name="isHomeDisplay" style="width:150px">									
                                                <option value="yes">Yes</option>
                                                <option value="no" <?php if ($isHomeDisplay == 'no') echo "selected"; ?>>No</option>
                                            </select>                                        
                                        </div>
                                    </td>
                                </tr>
                                <tr class="form-field form-required" >
                                    <th scope="row"><?php _e('Default Image Path', RBYTB_PLUGIN_NAME); ?></th>
                                    <td>
                                        <p class="description"><?php _e('Enter default image path when featured/content image not available  .', RBYTB_PLUGIN_NAME); ?></p>
                                        <div>
                                            <input type ="text" value="<?php echo $default_img_path; ?>" name="default_img_path" style="width:250px" />				
                                        </div>
                                    </td>
                                </tr>	

                            </tbody>
                        </table>
                        <p class="submit"><input type="submit" name="savesettings" id="savesettings" class="button button-primary" value="<?php _e('Save Changes', RBYTB_PLUGIN_NAME); ?>"></p> 
                    </form>

                </div>  
            </div>

        <?php
        }

    }

}
?>